@@ -370,7 +370,14 @@ class StateMachine:
             assert isinstance(job.node.callee, (Tree.Task, Tree.Workflow))
             callee_inputs = job.node.callee.available_inputs
             call_inputs = call_inputs.map(
-                lambda b: Env.Binding(b.name, b.value.coerce(callee_inputs[b.name].type))
+                lambda b: Env.Binding(
+                    b.name,
+                    (
+                        b.value.coerce(callee_inputs[b.name].type)
+                        if b.name in callee_inputs
+                        else b.value
+                    ),
+                )
             )
             # check input files against whitelist
             disallowed_filenames = _fspaths(call_inputs) - self.filename_whitelist
@@ -675,7 +682,9 @@ def run_local_workflow(
 
         # if we're the top-level workflow, provision thread pools
         if not _thread_pools:
-            import importlib_metadata  # delayed heavy import
+            # delayed heavy imports -- load .task_container now to work around python issue41567
+            import importlib_metadata
+            from .task_container import new as _new_task_container
 
             assert not _run_id_stack
             cache.flock(logfile, exclusive=True)  # flock top-level workflow.log
