@@ -108,6 +108,10 @@ class errors:
     class ImageNotFound(Exception):
         pass
 
+    class APIError(Exception):
+        def is_server_error(self) -> bool:
+            ...
+
 class DockerClient:
     @property
     def containers(self) -> Containers:
