@@ -375,7 +375,7 @@ class ENCODE_WGBS(unittest.TestCase):
         "UnusedCall": 16,
         "NameCollision": 2,
         "OptionalCoercion": 3,
-        "FileCoercion": 2,
+        "FileCoercion": 3,
         "StringCoercion": 2,
         "UnnecessaryQuantifier": 1,
         "MissingVersion": 52,
@@ -392,8 +392,8 @@ class dxWDL(unittest.TestCase):
         "_suppressions": 8,
         "UnusedImport": 4,
         "NameCollision": 27,
-        "StringCoercion": 4,
-        "FileCoercion": 2,
+        "StringCoercion": 6,
+        "FileCoercion": 3,
         "NonemptyCoercion": 1,
         "UnnecessaryQuantifier": 2,
         "UnusedDeclaration": 2,
@@ -402,6 +402,7 @@ class dxWDL(unittest.TestCase):
         "MissingVersion": 7,
         "UnboundDeclaration": 1,
         "UnverifiedStruct": 3,
+        "Deprecated": 2,
     },
     blacklist=["check_quant", "incomplete_call"],
 )
@@ -415,8 +416,8 @@ class Contrived(unittest.TestCase):
         "_suppressions": 16,
         "UnusedImport": 6,
         "NameCollision": 43,
-        "StringCoercion": 9,
-        "FileCoercion": 4,
+        "StringCoercion": 11,
+        "FileCoercion": 5,
         "OptionalCoercion": 3,
         "NonemptyCoercion": 2,
         "UnnecessaryQuantifier": 4,
@@ -427,6 +428,7 @@ class Contrived(unittest.TestCase):
         "MissingVersion": 11,
         "UnboundDeclaration": 1,
         "UnverifiedStruct": 3,
+        "Deprecated": 2,
     },
     check_quant=False,
     blacklist=["incomplete_call"],
